%------------------- LineshapeKin Simulation -----------------------------
%-- version 4.0 
%
% 5/8/09
% Written by Evgenii Kovrigin
% Medical College of Wisconsin
%
% 5/27/09 - full width at half-height for the spectra is determined for one-peak spectrum

function      [ spectral_figure, titration_curve_figure, titration_curve, line_width_curve_figure, line_width_curve] = SpectralFigure(w_range, spectral_series, Model, conditions, modes)
% Create spectral figure

global YES NO
WAIT_FOR_MINIMIUM=2;

%% Plot spectral series
spectral_figure = figure('XVisual',...
    '0x22 (TrueColor, depth 24, RGB mask 0xff0000 0xff00 0x00ff)',...
    'Color',[1 1 1]);

% Create axes
axes1 = axes('Parent',spectral_figure,'XDir','reverse','FontSize',16);
box('on');
xlim([conditions.w_min conditions.w_max])

hold('all');
% plot spectra


peak_maxima=[];
titration_curve=[];
line_width_curve=[];


% find maximum intensity for scaling
max_Intensity=0;
 for point_counter=1:conditions.total_titration_points
     %-- Record maximum intensity for scaling
     curr_max=max(spectral_series{point_counter});
     if curr_max>max_Intensity
         max_Intensity=curr_max;
     end
 end

% go from trace to trace
for point_counter=1:conditions.total_titration_points
    unshifted_peak_maxima=[];
    
    y= spectral_series{point_counter};
    % shift stacked spectra
    if modes.Stacked_Plot==YES
        y_shift=modes.Percent_Shift;
    else
        y_shift=0;
    end
    y_shifted=y+max_Intensity*y_shift*point_counter/100;
    % plot spectra
    dataname=sprintf('L/R= %.2f', conditions.LRratio(point_counter));
    plot(w_range,y_shifted,'DisplayName',dataname); hold on;
    
    % collect maxima
    %-- Search for maximum from the left
    downhill=NO;
    for w_counter=1:conditions.Spectral_Points-1
        if y(w_counter)>y(w_counter+1) && downhill==NO
            % maximum found
            %-- collect it for plotting on spectra
            peak_maxima = [ peak_maxima; [w_range(w_counter)  y_shifted(w_counter)]]; 
            %-- collect for line width determination
            unshifted_peak_maxima = [ unshifted_peak_maxima; [w_range(w_counter)  y(w_counter)]]; 
            %-- collect if for building a titration curve
            titration_curve= [titration_curve; [ conditions.LRratio(point_counter) w_range(w_counter)]];
            downhill=YES;
        end
        if y(w_counter)<y(w_counter+1) && downhill==YES
            % minimum passed
            downhill=NO;
        end
    end
    
   % here I detect line width at half-height assuming I have only one peak in the spectrum 
   [total_peaks,M]=size(unshifted_peak_maxima);
   peak_counter=1;
   max_y=unshifted_peak_maxima(peak_counter,2)/2; % set out to search for the first peak FWHH
   downhill=NO;
   for w_counter=1:conditions.Spectral_Points-1
      % search for the front sholder
      if y(w_counter)>=max_y && downhill==NO
          w_min=w_range(w_counter);
          downhill=YES;
      end
      % search for the rear shoulder
      if downhill==YES && y(w_counter)<max_y
         w_max=w_range(w_counter);
         downhill=WAIT_FOR_MINIMIUM;
         dw=w_max-w_min;
         line_width_curve=[ line_width_curve; [ conditions.LRratio(point_counter) dw] ];
         
         % switch to the next peak
         if peak_counter==total_peaks
             break
         end
         peak_counter=peak_counter+1;
         max_y=unshifted_peak_maxima(peak_counter,2)/2; % set out to search for the first peak FWHH
      end
      
      % wait to pass the half-height of the next peak before searching for a new peak
      if downhill==WAIT_FOR_MINIMIUM &&  y(w_counter)<max_y
          downhill=NO;
      end
   
   end
     
    

end

% plot frequencies of pure states
if  ~isempty(peak_maxima)
    plot(peak_maxima(:,1),peak_maxima(:,2),'r.','MarkerSize',12)
end






Y=max(y_shifted);
for state_counter=1:Model.species
    plot([Model.w0(state_counter),Model.w0(state_counter)],[0,Y],'k:')
end
% Create xlabel
xlabel('Frequency, s^{-1}','FontSize',18);
% Create ylabel
ylabel('Relative intensity','FontSize',18);

% Create title
title(Model.name,'Interpreter','none','FontSize',24);







%% Plot 'titration curve'
titration_curve_figure=figure('XVisual',...
    '0x22 (TrueColor, depth 24, RGB mask 0xff0000 0xff00 0x00ff)',...
    'Color',[1 1 1]);

Xmax=max(conditions.LRratio)*modes.extend_factor ;
TicksRange=0:0.2:Xmax;


% Create axes
axes('Parent',titration_curve_figure, 'XTick',TicksRange,'YGrid','on','XGrid','on','FontSize',16);
xlim([0 Xmax]);
box('on');
hold('all');

plot(titration_curve(:,1),titration_curve(:,2),'k.','MarkerSize',20)


% Create xlabel
ylabel('Peak position, s^{-1}','FontSize',18);
% Create ylabel
xlabel('L/R, mol/mol','FontSize',18);
ylim([conditions.w_min conditions.w_max]); 

% Create title
title(Model.name,'Interpreter','none','FontSize',24);


%% Plot 'line width curve'
line_width_curve_figure=figure('XVisual',...
    '0x22 (TrueColor, depth 24, RGB mask 0xff0000 0xff00 0x00ff)',...
    'Color',[1 1 1]);

Xmax=max(conditions.LRratio)*modes.extend_factor ;
TicksRange=0:0.2:Xmax;


% Create axes
axes('Parent',line_width_curve_figure, 'XTick',TicksRange,'YGrid','on','XGrid','on','FontSize',16);
xlim([0 Xmax]);
box('on');
hold('all');


plot(line_width_curve(:,1),line_width_curve(:,2),'k.','MarkerSize',20)


% Create xlabel
ylabel('Full width at half height, s^{-1}','FontSize',18);
% Create ylabel
xlabel('L/R, mol/mol','FontSize',18);
ylim([0 max(line_width_curve(:,2))*modes.extend_factor ]); 

% Create title
title(Model.name,'Interpreter','none','FontSize',24);



